@@ -153,7 +153,7 @@ KPtyPrivate::~KPtyPrivate()
 #if ! HAVE_OPENPTY
 bool KPtyPrivate::chownpty(bool grant)
 {
-    return !QProcess::execute(QFile::decodeName(CMAKE_INSTALL_PREFIX "/" KF5_LIBEXEC_INSTALL_DIR "/kgrantpty"),
+    return !QProcess::execute(QFile::decodeName(CMAKE_INSTALL_PREFIX "/" KDE_INSTALL_LIBEXECDIR_KF5 "/kgrantpty"),
                               QStringList() << (grant ? "--grant" : "--revoke") << QString::number(masterFd));
 }
 #endif
@@ -176,7 +176,6 @@ KPty::KPty(KPtyPrivate *d) :
 KPty::~KPty()
 {
     close();
-    delete d_ptr;
 }
 
 bool KPty::open()
